#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SubAntSignResult(object):

    def __init__(self):
        self._our_user_id = None
        self._related_business = None
        self._sign_task_id = None
        self._sub_biz_no = None

    @property
    def our_user_id(self):
        return self._our_user_id

    @our_user_id.setter
    def our_user_id(self, value):
        self._our_user_id = value
    @property
    def related_business(self):
        return self._related_business

    @related_business.setter
    def related_business(self, value):
        self._related_business = value
    @property
    def sign_task_id(self):
        return self._sign_task_id

    @sign_task_id.setter
    def sign_task_id(self, value):
        self._sign_task_id = value
    @property
    def sub_biz_no(self):
        return self._sub_biz_no

    @sub_biz_no.setter
    def sub_biz_no(self, value):
        self._sub_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.our_user_id:
            if hasattr(self.our_user_id, 'to_alipay_dict'):
                params['our_user_id'] = self.our_user_id.to_alipay_dict()
            else:
                params['our_user_id'] = self.our_user_id
        if self.related_business:
            if hasattr(self.related_business, 'to_alipay_dict'):
                params['related_business'] = self.related_business.to_alipay_dict()
            else:
                params['related_business'] = self.related_business
        if self.sign_task_id:
            if hasattr(self.sign_task_id, 'to_alipay_dict'):
                params['sign_task_id'] = self.sign_task_id.to_alipay_dict()
            else:
                params['sign_task_id'] = self.sign_task_id
        if self.sub_biz_no:
            if hasattr(self.sub_biz_no, 'to_alipay_dict'):
                params['sub_biz_no'] = self.sub_biz_no.to_alipay_dict()
            else:
                params['sub_biz_no'] = self.sub_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SubAntSignResult()
        if 'our_user_id' in d:
            o.our_user_id = d['our_user_id']
        if 'related_business' in d:
            o.related_business = d['related_business']
        if 'sign_task_id' in d:
            o.sign_task_id = d['sign_task_id']
        if 'sub_biz_no' in d:
            o.sub_biz_no = d['sub_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BindedMiniAppInfo import BindedMiniAppInfo


class AlipayOpenMiniAmpeBindedminiappBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniAmpeBindedminiappBatchqueryResponse, self).__init__()
        self._binded_mini_app_list = None
        self._total_count = None

    @property
    def binded_mini_app_list(self):
        return self._binded_mini_app_list

    @binded_mini_app_list.setter
    def binded_mini_app_list(self, value):
        if isinstance(value, list):
            self._binded_mini_app_list = list()
            for i in value:
                if isinstance(i, BindedMiniAppInfo):
                    self._binded_mini_app_list.append(i)
                else:
                    self._binded_mini_app_list.append(BindedMiniAppInfo.from_alipay_dict(i))
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniAmpeBindedminiappBatchqueryResponse, self).parse_response_content(response_content)
        if 'binded_mini_app_list' in response:
            self.binded_mini_app_list = response['binded_mini_app_list']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceExpensecontrolAggregationCreateModel(object):

    def __init__(self):
        self._account_id = None
        self._aggregation_name = None
        self._agreement_no = None
        self._standard_id_list = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def aggregation_name(self):
        return self._aggregation_name

    @aggregation_name.setter
    def aggregation_name(self, value):
        self._aggregation_name = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def standard_id_list(self):
        return self._standard_id_list

    @standard_id_list.setter
    def standard_id_list(self, value):
        if isinstance(value, list):
            self._standard_id_list = list()
            for i in value:
                self._standard_id_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.aggregation_name:
            if hasattr(self.aggregation_name, 'to_alipay_dict'):
                params['aggregation_name'] = self.aggregation_name.to_alipay_dict()
            else:
                params['aggregation_name'] = self.aggregation_name
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.standard_id_list:
            if isinstance(self.standard_id_list, list):
                for i in range(0, len(self.standard_id_list)):
                    element = self.standard_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.standard_id_list[i] = element.to_alipay_dict()
            if hasattr(self.standard_id_list, 'to_alipay_dict'):
                params['standard_id_list'] = self.standard_id_list.to_alipay_dict()
            else:
                params['standard_id_list'] = self.standard_id_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceExpensecontrolAggregationCreateModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'aggregation_name' in d:
            o.aggregation_name = d['aggregation_name']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'standard_id_list' in d:
            o.standard_id_list = d['standard_id_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PreOrderResult(object):

    def __init__(self):
        self._app_id = None
        self._out_trade_no = None
        self._result_code = None
        self._success = None

    @property
    def app_id(self):
        return self._app_id

    @app_id.setter
    def app_id(self, value):
        self._app_id = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_id:
            if hasattr(self.app_id, 'to_alipay_dict'):
                params['app_id'] = self.app_id.to_alipay_dict()
            else:
                params['app_id'] = self.app_id
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PreOrderResult()
        if 'app_id' in d:
            o.app_id = d['app_id']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SnapshotDTO(object):

    def __init__(self):
        self._after_market_amount = None
        self._after_market_buy_volume = None
        self._after_market_price = None
        self._after_market_sell_volume = None
        self._after_market_trade_time = None
        self._after_market_trading_phase = None
        self._after_market_volume = None
        self._amount = None
        self._ask_price_1 = None
        self._ask_price_10 = None
        self._ask_price_2 = None
        self._ask_price_3 = None
        self._ask_price_4 = None
        self._ask_price_5 = None
        self._ask_price_6 = None
        self._ask_price_7 = None
        self._ask_price_8 = None
        self._ask_price_9 = None
        self._ask_volume_1 = None
        self._ask_volume_10 = None
        self._ask_volume_2 = None
        self._ask_volume_3 = None
        self._ask_volume_4 = None
        self._ask_volume_5 = None
        self._ask_volume_6 = None
        self._ask_volume_7 = None
        self._ask_volume_8 = None
        self._ask_volume_9 = None
        self._bid_price_1 = None
        self._bid_price_10 = None
        self._bid_price_2 = None
        self._bid_price_3 = None
        self._bid_price_4 = None
        self._bid_price_5 = None
        self._bid_price_6 = None
        self._bid_price_7 = None
        self._bid_price_8 = None
        self._bid_price_9 = None
        self._bid_volume_1 = None
        self._bid_volume_10 = None
        self._bid_volume_2 = None
        self._bid_volume_3 = None
        self._bid_volume_4 = None
        self._bid_volume_5 = None
        self._bid_volume_6 = None
        self._bid_volume_7 = None
        self._bid_volume_8 = None
        self._bid_volume_9 = None
        self._change_percent = None
        self._change_price = None
        self._close_price = None
        self._date = None
        self._down_price = None
        self._high_price = None
        self._low_price = None
        self._name = None
        self._open_price = None
        self._previous_close = None
        self._price = None
        self._suspension_state = None
        self._symbol = None
        self._trade_state = None
        self._up_price = None
        self._volume = None

    @property
    def after_market_amount(self):
        return self._after_market_amount

    @after_market_amount.setter
    def after_market_amount(self, value):
        self._after_market_amount = value
    @property
    def after_market_buy_volume(self):
        return self._after_market_buy_volume

    @after_market_buy_volume.setter
    def after_market_buy_volume(self, value):
        self._after_market_buy_volume = value
    @property
    def after_market_price(self):
        return self._after_market_price

    @after_market_price.setter
    def after_market_price(self, value):
        self._after_market_price = value
    @property
    def after_market_sell_volume(self):
        return self._after_market_sell_volume

    @after_market_sell_volume.setter
    def after_market_sell_volume(self, value):
        self._after_market_sell_volume = value
    @property
    def after_market_trade_time(self):
        return self._after_market_trade_time

    @after_market_trade_time.setter
    def after_market_trade_time(self, value):
        self._after_market_trade_time = value
    @property
    def after_market_trading_phase(self):
        return self._after_market_trading_phase

    @after_market_trading_phase.setter
    def after_market_trading_phase(self, value):
        self._after_market_trading_phase = value
    @property
    def after_market_volume(self):
        return self._after_market_volume

    @after_market_volume.setter
    def after_market_volume(self, value):
        self._after_market_volume = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def ask_price_1(self):
        return self._ask_price_1

    @ask_price_1.setter
    def ask_price_1(self, value):
        self._ask_price_1 = value
    @property
    def ask_price_10(self):
        return self._ask_price_10

    @ask_price_10.setter
    def ask_price_10(self, value):
        self._ask_price_10 = value
    @property
    def ask_price_2(self):
        return self._ask_price_2

    @ask_price_2.setter
    def ask_price_2(self, value):
        self._ask_price_2 = value
    @property
    def ask_price_3(self):
        return self._ask_price_3

    @ask_price_3.setter
    def ask_price_3(self, value):
        self._ask_price_3 = value
    @property
    def ask_price_4(self):
        return self._ask_price_4

    @ask_price_4.setter
    def ask_price_4(self, value):
        self._ask_price_4 = value
    @property
    def ask_price_5(self):
        return self._ask_price_5

    @ask_price_5.setter
    def ask_price_5(self, value):
        self._ask_price_5 = value
    @property
    def ask_price_6(self):
        return self._ask_price_6

    @ask_price_6.setter
    def ask_price_6(self, value):
        self._ask_price_6 = value
    @property
    def ask_price_7(self):
        return self._ask_price_7

    @ask_price_7.setter
    def ask_price_7(self, value):
        self._ask_price_7 = value
    @property
    def ask_price_8(self):
        return self._ask_price_8

    @ask_price_8.setter
    def ask_price_8(self, value):
        self._ask_price_8 = value
    @property
    def ask_price_9(self):
        return self._ask_price_9

    @ask_price_9.setter
    def ask_price_9(self, value):
        self._ask_price_9 = value
    @property
    def ask_volume_1(self):
        return self._ask_volume_1

    @ask_volume_1.setter
    def ask_volume_1(self, value):
        self._ask_volume_1 = value
    @property
    def ask_volume_10(self):
        return self._ask_volume_10

    @ask_volume_10.setter
    def ask_volume_10(self, value):
        self._ask_volume_10 = value
    @property
    def ask_volume_2(self):
        return self._ask_volume_2

    @ask_volume_2.setter
    def ask_volume_2(self, value):
        self._ask_volume_2 = value
    @property
    def ask_volume_3(self):
        return self._ask_volume_3

    @ask_volume_3.setter
    def ask_volume_3(self, value):
        self._ask_volume_3 = value
    @property
    def ask_volume_4(self):
        return self._ask_volume_4

    @ask_volume_4.setter
    def ask_volume_4(self, value):
        self._ask_volume_4 = value
    @property
    def ask_volume_5(self):
        return self._ask_volume_5

    @ask_volume_5.setter
    def ask_volume_5(self, value):
        self._ask_volume_5 = value
    @property
    def ask_volume_6(self):
        return self._ask_volume_6

    @ask_volume_6.setter
    def ask_volume_6(self, value):
        self._ask_volume_6 = value
    @property
    def ask_volume_7(self):
        return self._ask_volume_7

    @ask_volume_7.setter
    def ask_volume_7(self, value):
        self._ask_volume_7 = value
    @property
    def ask_volume_8(self):
        return self._ask_volume_8

    @ask_volume_8.setter
    def ask_volume_8(self, value):
        self._ask_volume_8 = value
    @property
    def ask_volume_9(self):
        return self._ask_volume_9

    @ask_volume_9.setter
    def ask_volume_9(self, value):
        self._ask_volume_9 = value
    @property
    def bid_price_1(self):
        return self._bid_price_1

    @bid_price_1.setter
    def bid_price_1(self, value):
        self._bid_price_1 = value
    @property
    def bid_price_10(self):
        return self._bid_price_10

    @bid_price_10.setter
    def bid_price_10(self, value):
        self._bid_price_10 = value
    @property
    def bid_price_2(self):
        return self._bid_price_2

    @bid_price_2.setter
    def bid_price_2(self, value):
        self._bid_price_2 = value
    @property
    def bid_price_3(self):
        return self._bid_price_3

    @bid_price_3.setter
    def bid_price_3(self, value):
        self._bid_price_3 = value
    @property
    def bid_price_4(self):
        return self._bid_price_4

    @bid_price_4.setter
    def bid_price_4(self, value):
        self._bid_price_4 = value
    @property
    def bid_price_5(self):
        return self._bid_price_5

    @bid_price_5.setter
    def bid_price_5(self, value):
        self._bid_price_5 = value
    @property
    def bid_price_6(self):
        return self._bid_price_6

    @bid_price_6.setter
    def bid_price_6(self, value):
        self._bid_price_6 = value
    @property
    def bid_price_7(self):
        return self._bid_price_7

    @bid_price_7.setter
    def bid_price_7(self, value):
        self._bid_price_7 = value
    @property
    def bid_price_8(self):
        return self._bid_price_8

    @bid_price_8.setter
    def bid_price_8(self, value):
        self._bid_price_8 = value
    @property
    def bid_price_9(self):
        return self._bid_price_9

    @bid_price_9.setter
    def bid_price_9(self, value):
        self._bid_price_9 = value
    @property
    def bid_volume_1(self):
        return self._bid_volume_1

    @bid_volume_1.setter
    def bid_volume_1(self, value):
        self._bid_volume_1 = value
    @property
    def bid_volume_10(self):
        return self._bid_volume_10

    @bid_volume_10.setter
    def bid_volume_10(self, value):
        self._bid_volume_10 = value
    @property
    def bid_volume_2(self):
        return self._bid_volume_2

    @bid_volume_2.setter
    def bid_volume_2(self, value):
        self._bid_volume_2 = value
    @property
    def bid_volume_3(self):
        return self._bid_volume_3

    @bid_volume_3.setter
    def bid_volume_3(self, value):
        self._bid_volume_3 = value
    @property
    def bid_volume_4(self):
        return self._bid_volume_4

    @bid_volume_4.setter
    def bid_volume_4(self, value):
        self._bid_volume_4 = value
    @property
    def bid_volume_5(self):
        return self._bid_volume_5

    @bid_volume_5.setter
    def bid_volume_5(self, value):
        self._bid_volume_5 = value
    @property
    def bid_volume_6(self):
        return self._bid_volume_6

    @bid_volume_6.setter
    def bid_volume_6(self, value):
        self._bid_volume_6 = value
    @property
    def bid_volume_7(self):
        return self._bid_volume_7

    @bid_volume_7.setter
    def bid_volume_7(self, value):
        self._bid_volume_7 = value
    @property
    def bid_volume_8(self):
        return self._bid_volume_8

    @bid_volume_8.setter
    def bid_volume_8(self, value):
        self._bid_volume_8 = value
    @property
    def bid_volume_9(self):
        return self._bid_volume_9

    @bid_volume_9.setter
    def bid_volume_9(self, value):
        self._bid_volume_9 = value
    @property
    def change_percent(self):
        return self._change_percent

    @change_percent.setter
    def change_percent(self, value):
        self._change_percent = value
    @property
    def change_price(self):
        return self._change_price

    @change_price.setter
    def change_price(self, value):
        self._change_price = value
    @property
    def close_price(self):
        return self._close_price

    @close_price.setter
    def close_price(self, value):
        self._close_price = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def down_price(self):
        return self._down_price

    @down_price.setter
    def down_price(self, value):
        self._down_price = value
    @property
    def high_price(self):
        return self._high_price

    @high_price.setter
    def high_price(self, value):
        self._high_price = value
    @property
    def low_price(self):
        return self._low_price

    @low_price.setter
    def low_price(self, value):
        self._low_price = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def open_price(self):
        return self._open_price

    @open_price.setter
    def open_price(self, value):
        self._open_price = value
    @property
    def previous_close(self):
        return self._previous_close

    @previous_close.setter
    def previous_close(self, value):
        self._previous_close = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def suspension_state(self):
        return self._suspension_state

    @suspension_state.setter
    def suspension_state(self, value):
        self._suspension_state = value
    @property
    def symbol(self):
        return self._symbol

    @symbol.setter
    def symbol(self, value):
        self._symbol = value
    @property
    def trade_state(self):
        return self._trade_state

    @trade_state.setter
    def trade_state(self, value):
        self._trade_state = value
    @property
    def up_price(self):
        return self._up_price

    @up_price.setter
    def up_price(self, value):
        self._up_price = value
    @property
    def volume(self):
        return self._volume

    @volume.setter
    def volume(self, value):
        self._volume = value


    def to_alipay_dict(self):
        params = dict()
        if self.after_market_amount:
            if hasattr(self.after_market_amount, 'to_alipay_dict'):
                params['after_market_amount'] = self.after_market_amount.to_alipay_dict()
            else:
                params['after_market_amount'] = self.after_market_amount
        if self.after_market_buy_volume:
            if hasattr(self.after_market_buy_volume, 'to_alipay_dict'):
                params['after_market_buy_volume'] = self.after_market_buy_volume.to_alipay_dict()
            else:
                params['after_market_buy_volume'] = self.after_market_buy_volume
        if self.after_market_price:
            if hasattr(self.after_market_price, 'to_alipay_dict'):
                params['after_market_price'] = self.after_market_price.to_alipay_dict()
            else:
                params['after_market_price'] = self.after_market_price
        if self.after_market_sell_volume:
            if hasattr(self.after_market_sell_volume, 'to_alipay_dict'):
                params['after_market_sell_volume'] = self.after_market_sell_volume.to_alipay_dict()
            else:
                params['after_market_sell_volume'] = self.after_market_sell_volume
        if self.after_market_trade_time:
            if hasattr(self.after_market_trade_time, 'to_alipay_dict'):
                params['after_market_trade_time'] = self.after_market_trade_time.to_alipay_dict()
            else:
                params['after_market_trade_time'] = self.after_market_trade_time
        if self.after_market_trading_phase:
            if hasattr(self.after_market_trading_phase, 'to_alipay_dict'):
                params['after_market_trading_phase'] = self.after_market_trading_phase.to_alipay_dict()
            else:
                params['after_market_trading_phase'] = self.after_market_trading_phase
        if self.after_market_volume:
            if hasattr(self.after_market_volume, 'to_alipay_dict'):
                params['after_market_volume'] = self.after_market_volume.to_alipay_dict()
            else:
                params['after_market_volume'] = self.after_market_volume
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.ask_price_1:
            if hasattr(self.ask_price_1, 'to_alipay_dict'):
                params['ask_price_1'] = self.ask_price_1.to_alipay_dict()
            else:
                params['ask_price_1'] = self.ask_price_1
        if self.ask_price_10:
            if hasattr(self.ask_price_10, 'to_alipay_dict'):
                params['ask_price_10'] = self.ask_price_10.to_alipay_dict()
            else:
                params['ask_price_10'] = self.ask_price_10
        if self.ask_price_2:
            if hasattr(self.ask_price_2, 'to_alipay_dict'):
                params['ask_price_2'] = self.ask_price_2.to_alipay_dict()
            else:
                params['ask_price_2'] = self.ask_price_2
        if self.ask_price_3:
            if hasattr(self.ask_price_3, 'to_alipay_dict'):
                params['ask_price_3'] = self.ask_price_3.to_alipay_dict()
            else:
                params['ask_price_3'] = self.ask_price_3
        if self.ask_price_4:
            if hasattr(self.ask_price_4, 'to_alipay_dict'):
                params['ask_price_4'] = self.ask_price_4.to_alipay_dict()
            else:
                params['ask_price_4'] = self.ask_price_4
        if self.ask_price_5:
            if hasattr(self.ask_price_5, 'to_alipay_dict'):
                params['ask_price_5'] = self.ask_price_5.to_alipay_dict()
            else:
                params['ask_price_5'] = self.ask_price_5
        if self.ask_price_6:
            if hasattr(self.ask_price_6, 'to_alipay_dict'):
                params['ask_price_6'] = self.ask_price_6.to_alipay_dict()
            else:
                params['ask_price_6'] = self.ask_price_6
        if self.ask_price_7:
            if hasattr(self.ask_price_7, 'to_alipay_dict'):
                params['ask_price_7'] = self.ask_price_7.to_alipay_dict()
            else:
                params['ask_price_7'] = self.ask_price_7
        if self.ask_price_8:
            if hasattr(self.ask_price_8, 'to_alipay_dict'):
                params['ask_price_8'] = self.ask_price_8.to_alipay_dict()
            else:
                params['ask_price_8'] = self.ask_price_8
        if self.ask_price_9:
            if hasattr(self.ask_price_9, 'to_alipay_dict'):
                params['ask_price_9'] = self.ask_price_9.to_alipay_dict()
            else:
                params['ask_price_9'] = self.ask_price_9
        if self.ask_volume_1:
            if hasattr(self.ask_volume_1, 'to_alipay_dict'):
                params['ask_volume_1'] = self.ask_volume_1.to_alipay_dict()
            else:
                params['ask_volume_1'] = self.ask_volume_1
        if self.ask_volume_10:
            if hasattr(self.ask_volume_10, 'to_alipay_dict'):
                params['ask_volume_10'] = self.ask_volume_10.to_alipay_dict()
            else:
                params['ask_volume_10'] = self.ask_volume_10
        if self.ask_volume_2:
            if hasattr(self.ask_volume_2, 'to_alipay_dict'):
                params['ask_volume_2'] = self.ask_volume_2.to_alipay_dict()
            else:
                params['ask_volume_2'] = self.ask_volume_2
        if self.ask_volume_3:
            if hasattr(self.ask_volume_3, 'to_alipay_dict'):
                params['ask_volume_3'] = self.ask_volume_3.to_alipay_dict()
            else:
                params['ask_volume_3'] = self.ask_volume_3
        if self.ask_volume_4:
            if hasattr(self.ask_volume_4, 'to_alipay_dict'):
                params['ask_volume_4'] = self.ask_volume_4.to_alipay_dict()
            else:
                params['ask_volume_4'] = self.ask_volume_4
        if self.ask_volume_5:
            if hasattr(self.ask_volume_5, 'to_alipay_dict'):
                params['ask_volume_5'] = self.ask_volume_5.to_alipay_dict()
            else:
                params['ask_volume_5'] = self.ask_volume_5
        if self.ask_volume_6:
            if hasattr(self.ask_volume_6, 'to_alipay_dict'):
                params['ask_volume_6'] = self.ask_volume_6.to_alipay_dict()
            else:
                params['ask_volume_6'] = self.ask_volume_6
        if self.ask_volume_7:
            if hasattr(self.ask_volume_7, 'to_alipay_dict'):
                params['ask_volume_7'] = self.ask_volume_7.to_alipay_dict()
            else:
                params['ask_volume_7'] = self.ask_volume_7
        if self.ask_volume_8:
            if hasattr(self.ask_volume_8, 'to_alipay_dict'):
                params['ask_volume_8'] = self.ask_volume_8.to_alipay_dict()
            else:
                params['ask_volume_8'] = self.ask_volume_8
        if self.ask_volume_9:
            if hasattr(self.ask_volume_9, 'to_alipay_dict'):
                params['ask_volume_9'] = self.ask_volume_9.to_alipay_dict()
            else:
                params['ask_volume_9'] = self.ask_volume_9
        if self.bid_price_1:
            if hasattr(self.bid_price_1, 'to_alipay_dict'):
                params['bid_price_1'] = self.bid_price_1.to_alipay_dict()
            else:
                params['bid_price_1'] = self.bid_price_1
        if self.bid_price_10:
            if hasattr(self.bid_price_10, 'to_alipay_dict'):
                params['bid_price_10'] = self.bid_price_10.to_alipay_dict()
            else:
                params['bid_price_10'] = self.bid_price_10
        if self.bid_price_2:
            if hasattr(self.bid_price_2, 'to_alipay_dict'):
                params['bid_price_2'] = self.bid_price_2.to_alipay_dict()
            else:
                params['bid_price_2'] = self.bid_price_2
        if self.bid_price_3:
            if hasattr(self.bid_price_3, 'to_alipay_dict'):
                params['bid_price_3'] = self.bid_price_3.to_alipay_dict()
            else:
                params['bid_price_3'] = self.bid_price_3
        if self.bid_price_4:
            if hasattr(self.bid_price_4, 'to_alipay_dict'):
                params['bid_price_4'] = self.bid_price_4.to_alipay_dict()
            else:
                params['bid_price_4'] = self.bid_price_4
        if self.bid_price_5:
            if hasattr(self.bid_price_5, 'to_alipay_dict'):
                params['bid_price_5'] = self.bid_price_5.to_alipay_dict()
            else:
                params['bid_price_5'] = self.bid_price_5
        if self.bid_price_6:
            if hasattr(self.bid_price_6, 'to_alipay_dict'):
                params['bid_price_6'] = self.bid_price_6.to_alipay_dict()
            else:
                params['bid_price_6'] = self.bid_price_6
        if self.bid_price_7:
            if hasattr(self.bid_price_7, 'to_alipay_dict'):
                params['bid_price_7'] = self.bid_price_7.to_alipay_dict()
            else:
                params['bid_price_7'] = self.bid_price_7
        if self.bid_price_8:
            if hasattr(self.bid_price_8, 'to_alipay_dict'):
                params['bid_price_8'] = self.bid_price_8.to_alipay_dict()
            else:
                params['bid_price_8'] = self.bid_price_8
        if self.bid_price_9:
            if hasattr(self.bid_price_9, 'to_alipay_dict'):
                params['bid_price_9'] = self.bid_price_9.to_alipay_dict()
            else:
                params['bid_price_9'] = self.bid_price_9
        if self.bid_volume_1:
            if hasattr(self.bid_volume_1, 'to_alipay_dict'):
                params['bid_volume_1'] = self.bid_volume_1.to_alipay_dict()
            else:
                params['bid_volume_1'] = self.bid_volume_1
        if self.bid_volume_10:
            if hasattr(self.bid_volume_10, 'to_alipay_dict'):
                params['bid_volume_10'] = self.bid_volume_10.to_alipay_dict()
            else:
                params['bid_volume_10'] = self.bid_volume_10
        if self.bid_volume_2:
            if hasattr(self.bid_volume_2, 'to_alipay_dict'):
                params['bid_volume_2'] = self.bid_volume_2.to_alipay_dict()
            else:
                params['bid_volume_2'] = self.bid_volume_2
        if self.bid_volume_3:
            if hasattr(self.bid_volume_3, 'to_alipay_dict'):
                params['bid_volume_3'] = self.bid_volume_3.to_alipay_dict()
            else:
                params['bid_volume_3'] = self.bid_volume_3
        if self.bid_volume_4:
            if hasattr(self.bid_volume_4, 'to_alipay_dict'):
                params['bid_volume_4'] = self.bid_volume_4.to_alipay_dict()
            else:
                params['bid_volume_4'] = self.bid_volume_4
        if self.bid_volume_5:
            if hasattr(self.bid_volume_5, 'to_alipay_dict'):
                params['bid_volume_5'] = self.bid_volume_5.to_alipay_dict()
            else:
                params['bid_volume_5'] = self.bid_volume_5
        if self.bid_volume_6:
            if hasattr(self.bid_volume_6, 'to_alipay_dict'):
                params['bid_volume_6'] = self.bid_volume_6.to_alipay_dict()
            else:
                params['bid_volume_6'] = self.bid_volume_6
        if self.bid_volume_7:
            if hasattr(self.bid_volume_7, 'to_alipay_dict'):
                params['bid_volume_7'] = self.bid_volume_7.to_alipay_dict()
            else:
                params['bid_volume_7'] = self.bid_volume_7
        if self.bid_volume_8:
            if hasattr(self.bid_volume_8, 'to_alipay_dict'):
                params['bid_volume_8'] = self.bid_volume_8.to_alipay_dict()
            else:
                params['bid_volume_8'] = self.bid_volume_8
        if self.bid_volume_9:
            if hasattr(self.bid_volume_9, 'to_alipay_dict'):
                params['bid_volume_9'] = self.bid_volume_9.to_alipay_dict()
            else:
                params['bid_volume_9'] = self.bid_volume_9
        if self.change_percent:
            if hasattr(self.change_percent, 'to_alipay_dict'):
                params['change_percent'] = self.change_percent.to_alipay_dict()
            else:
                params['change_percent'] = self.change_percent
        if self.change_price:
            if hasattr(self.change_price, 'to_alipay_dict'):
                params['change_price'] = self.change_price.to_alipay_dict()
            else:
                params['change_price'] = self.change_price
        if self.close_price:
            if hasattr(self.close_price, 'to_alipay_dict'):
                params['close_price'] = self.close_price.to_alipay_dict()
            else:
                params['close_price'] = self.close_price
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.down_price:
            if hasattr(self.down_price, 'to_alipay_dict'):
                params['down_price'] = self.down_price.to_alipay_dict()
            else:
                params['down_price'] = self.down_price
        if self.high_price:
            if hasattr(self.high_price, 'to_alipay_dict'):
                params['high_price'] = self.high_price.to_alipay_dict()
            else:
                params['high_price'] = self.high_price
        if self.low_price:
            if hasattr(self.low_price, 'to_alipay_dict'):
                params['low_price'] = self.low_price.to_alipay_dict()
            else:
                params['low_price'] = self.low_price
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.open_price:
            if hasattr(self.open_price, 'to_alipay_dict'):
                params['open_price'] = self.open_price.to_alipay_dict()
            else:
                params['open_price'] = self.open_price
        if self.previous_close:
            if hasattr(self.previous_close, 'to_alipay_dict'):
                params['previous_close'] = self.previous_close.to_alipay_dict()
            else:
                params['previous_close'] = self.previous_close
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.suspension_state:
            if hasattr(self.suspension_state, 'to_alipay_dict'):
                params['suspension_state'] = self.suspension_state.to_alipay_dict()
            else:
                params['suspension_state'] = self.suspension_state
        if self.symbol:
            if hasattr(self.symbol, 'to_alipay_dict'):
                params['symbol'] = self.symbol.to_alipay_dict()
            else:
                params['symbol'] = self.symbol
        if self.trade_state:
            if hasattr(self.trade_state, 'to_alipay_dict'):
                params['trade_state'] = self.trade_state.to_alipay_dict()
            else:
                params['trade_state'] = self.trade_state
        if self.up_price:
            if hasattr(self.up_price, 'to_alipay_dict'):
                params['up_price'] = self.up_price.to_alipay_dict()
            else:
                params['up_price'] = self.up_price
        if self.volume:
            if hasattr(self.volume, 'to_alipay_dict'):
                params['volume'] = self.volume.to_alipay_dict()
            else:
                params['volume'] = self.volume
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SnapshotDTO()
        if 'after_market_amount' in d:
            o.after_market_amount = d['after_market_amount']
        if 'after_market_buy_volume' in d:
            o.after_market_buy_volume = d['after_market_buy_volume']
        if 'after_market_price' in d:
            o.after_market_price = d['after_market_price']
        if 'after_market_sell_volume' in d:
            o.after_market_sell_volume = d['after_market_sell_volume']
        if 'after_market_trade_time' in d:
            o.after_market_trade_time = d['after_market_trade_time']
        if 'after_market_trading_phase' in d:
            o.after_market_trading_phase = d['after_market_trading_phase']
        if 'after_market_volume' in d:
            o.after_market_volume = d['after_market_volume']
        if 'amount' in d:
            o.amount = d['amount']
        if 'ask_price_1' in d:
            o.ask_price_1 = d['ask_price_1']
        if 'ask_price_10' in d:
            o.ask_price_10 = d['ask_price_10']
        if 'ask_price_2' in d:
            o.ask_price_2 = d['ask_price_2']
        if 'ask_price_3' in d:
            o.ask_price_3 = d['ask_price_3']
        if 'ask_price_4' in d:
            o.ask_price_4 = d['ask_price_4']
        if 'ask_price_5' in d:
            o.ask_price_5 = d['ask_price_5']
        if 'ask_price_6' in d:
            o.ask_price_6 = d['ask_price_6']
        if 'ask_price_7' in d:
            o.ask_price_7 = d['ask_price_7']
        if 'ask_price_8' in d:
            o.ask_price_8 = d['ask_price_8']
        if 'ask_price_9' in d:
            o.ask_price_9 = d['ask_price_9']
        if 'ask_volume_1' in d:
            o.ask_volume_1 = d['ask_volume_1']
        if 'ask_volume_10' in d:
            o.ask_volume_10 = d['ask_volume_10']
        if 'ask_volume_2' in d:
            o.ask_volume_2 = d['ask_volume_2']
        if 'ask_volume_3' in d:
            o.ask_volume_3 = d['ask_volume_3']
        if 'ask_volume_4' in d:
            o.ask_volume_4 = d['ask_volume_4']
        if 'ask_volume_5' in d:
            o.ask_volume_5 = d['ask_volume_5']
        if 'ask_volume_6' in d:
            o.ask_volume_6 = d['ask_volume_6']
        if 'ask_volume_7' in d:
            o.ask_volume_7 = d['ask_volume_7']
        if 'ask_volume_8' in d:
            o.ask_volume_8 = d['ask_volume_8']
        if 'ask_volume_9' in d:
            o.ask_volume_9 = d['ask_volume_9']
        if 'bid_price_1' in d:
            o.bid_price_1 = d['bid_price_1']
        if 'bid_price_10' in d:
            o.bid_price_10 = d['bid_price_10']
        if 'bid_price_2' in d:
            o.bid_price_2 = d['bid_price_2']
        if 'bid_price_3' in d:
            o.bid_price_3 = d['bid_price_3']
        if 'bid_price_4' in d:
            o.bid_price_4 = d['bid_price_4']
        if 'bid_price_5' in d:
            o.bid_price_5 = d['bid_price_5']
        if 'bid_price_6' in d:
            o.bid_price_6 = d['bid_price_6']
        if 'bid_price_7' in d:
            o.bid_price_7 = d['bid_price_7']
        if 'bid_price_8' in d:
            o.bid_price_8 = d['bid_price_8']
        if 'bid_price_9' in d:
            o.bid_price_9 = d['bid_price_9']
        if 'bid_volume_1' in d:
            o.bid_volume_1 = d['bid_volume_1']
        if 'bid_volume_10' in d:
            o.bid_volume_10 = d['bid_volume_10']
        if 'bid_volume_2' in d:
            o.bid_volume_2 = d['bid_volume_2']
        if 'bid_volume_3' in d:
            o.bid_volume_3 = d['bid_volume_3']
        if 'bid_volume_4' in d:
            o.bid_volume_4 = d['bid_volume_4']
        if 'bid_volume_5' in d:
            o.bid_volume_5 = d['bid_volume_5']
        if 'bid_volume_6' in d:
            o.bid_volume_6 = d['bid_volume_6']
        if 'bid_volume_7' in d:
            o.bid_volume_7 = d['bid_volume_7']
        if 'bid_volume_8' in d:
            o.bid_volume_8 = d['bid_volume_8']
        if 'bid_volume_9' in d:
            o.bid_volume_9 = d['bid_volume_9']
        if 'change_percent' in d:
            o.change_percent = d['change_percent']
        if 'change_price' in d:
            o.change_price = d['change_price']
        if 'close_price' in d:
            o.close_price = d['close_price']
        if 'date' in d:
            o.date = d['date']
        if 'down_price' in d:
            o.down_price = d['down_price']
        if 'high_price' in d:
            o.high_price = d['high_price']
        if 'low_price' in d:
            o.low_price = d['low_price']
        if 'name' in d:
            o.name = d['name']
        if 'open_price' in d:
            o.open_price = d['open_price']
        if 'previous_close' in d:
            o.previous_close = d['previous_close']
        if 'price' in d:
            o.price = d['price']
        if 'suspension_state' in d:
            o.suspension_state = d['suspension_state']
        if 'symbol' in d:
            o.symbol = d['symbol']
        if 'trade_state' in d:
            o.trade_state = d['trade_state']
        if 'up_price' in d:
            o.up_price = d['up_price']
        if 'volume' in d:
            o.volume = d['volume']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniAutocheckCaseQueryModel(object):

    def __init__(self):
        self._case_id = None
        self._case_name = None

    @property
    def case_id(self):
        return self._case_id

    @case_id.setter
    def case_id(self, value):
        self._case_id = value
    @property
    def case_name(self):
        return self._case_name

    @case_name.setter
    def case_name(self, value):
        self._case_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.case_id:
            if hasattr(self.case_id, 'to_alipay_dict'):
                params['case_id'] = self.case_id.to_alipay_dict()
            else:
                params['case_id'] = self.case_id
        if self.case_name:
            if hasattr(self.case_name, 'to_alipay_dict'):
                params['case_name'] = self.case_name.to_alipay_dict()
            else:
                params['case_name'] = self.case_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniAutocheckCaseQueryModel()
        if 'case_id' in d:
            o.case_id = d['case_id']
        if 'case_name' in d:
            o.case_name = d['case_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IndirectSupportCredentials(object):

    def __init__(self):
        self._city = None
        self._city_code = None
        self._district = None
        self._district_code = None
        self._merchant_type = None
        self._province = None
        self._province_code = None
        self._store_address = None
        self._store_door_img = None
        self._store_inner_img = None
        self._store_name = None

    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def district(self):
        return self._district

    @district.setter
    def district(self, value):
        self._district = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def merchant_type(self):
        return self._merchant_type

    @merchant_type.setter
    def merchant_type(self, value):
        self._merchant_type = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def store_address(self):
        return self._store_address

    @store_address.setter
    def store_address(self, value):
        self._store_address = value
    @property
    def store_door_img(self):
        return self._store_door_img

    @store_door_img.setter
    def store_door_img(self, value):
        self._store_door_img = value
    @property
    def store_inner_img(self):
        return self._store_inner_img

    @store_inner_img.setter
    def store_inner_img(self, value):
        self._store_inner_img = value
    @property
    def store_name(self):
        return self._store_name

    @store_name.setter
    def store_name(self, value):
        self._store_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.district:
            if hasattr(self.district, 'to_alipay_dict'):
                params['district'] = self.district.to_alipay_dict()
            else:
                params['district'] = self.district
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.merchant_type:
            if hasattr(self.merchant_type, 'to_alipay_dict'):
                params['merchant_type'] = self.merchant_type.to_alipay_dict()
            else:
                params['merchant_type'] = self.merchant_type
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.store_address:
            if hasattr(self.store_address, 'to_alipay_dict'):
                params['store_address'] = self.store_address.to_alipay_dict()
            else:
                params['store_address'] = self.store_address
        if self.store_door_img:
            if hasattr(self.store_door_img, 'to_alipay_dict'):
                params['store_door_img'] = self.store_door_img.to_alipay_dict()
            else:
                params['store_door_img'] = self.store_door_img
        if self.store_inner_img:
            if hasattr(self.store_inner_img, 'to_alipay_dict'):
                params['store_inner_img'] = self.store_inner_img.to_alipay_dict()
            else:
                params['store_inner_img'] = self.store_inner_img
        if self.store_name:
            if hasattr(self.store_name, 'to_alipay_dict'):
                params['store_name'] = self.store_name.to_alipay_dict()
            else:
                params['store_name'] = self.store_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IndirectSupportCredentials()
        if 'city' in d:
            o.city = d['city']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'district' in d:
            o.district = d['district']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'merchant_type' in d:
            o.merchant_type = d['merchant_type']
        if 'province' in d:
            o.province = d['province']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'store_address' in d:
            o.store_address = d['store_address']
        if 'store_door_img' in d:
            o.store_door_img = d['store_door_img']
        if 'store_inner_img' in d:
            o.store_inner_img = d['store_inner_img']
        if 'store_name' in d:
            o.store_name = d['store_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCustomerContractRecordSyncModel(object):

    def __init__(self):
        self._biz_no = None
        self._biz_time = None
        self._biz_type = None
        self._contract_no = None
        self._record_content = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def contract_no(self):
        return self._contract_no

    @contract_no.setter
    def contract_no(self, value):
        self._contract_no = value
    @property
    def record_content(self):
        return self._record_content

    @record_content.setter
    def record_content(self, value):
        self._record_content = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.contract_no:
            if hasattr(self.contract_no, 'to_alipay_dict'):
                params['contract_no'] = self.contract_no.to_alipay_dict()
            else:
                params['contract_no'] = self.contract_no
        if self.record_content:
            if hasattr(self.record_content, 'to_alipay_dict'):
                params['record_content'] = self.record_content.to_alipay_dict()
            else:
                params['record_content'] = self.record_content
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerContractRecordSyncModel()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'contract_no' in d:
            o.contract_no = d['contract_no']
        if 'record_content' in d:
            o.record_content = d['record_content']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Org import Org


class SignerBean(object):

    def __init__(self):
        self._email = None
        self._id_number = None
        self._id_type = None
        self._mobile = None
        self._name = None
        self._org = None
        self._third_party_user_id = None

    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def id_number(self):
        return self._id_number

    @id_number.setter
    def id_number(self, value):
        self._id_number = value
    @property
    def id_type(self):
        return self._id_type

    @id_type.setter
    def id_type(self, value):
        self._id_type = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def org(self):
        return self._org

    @org.setter
    def org(self, value):
        if isinstance(value, Org):
            self._org = value
        else:
            self._org = Org.from_alipay_dict(value)
    @property
    def third_party_user_id(self):
        return self._third_party_user_id

    @third_party_user_id.setter
    def third_party_user_id(self, value):
        self._third_party_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.id_number:
            if hasattr(self.id_number, 'to_alipay_dict'):
                params['id_number'] = self.id_number.to_alipay_dict()
            else:
                params['id_number'] = self.id_number
        if self.id_type:
            if hasattr(self.id_type, 'to_alipay_dict'):
                params['id_type'] = self.id_type.to_alipay_dict()
            else:
                params['id_type'] = self.id_type
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.org:
            if hasattr(self.org, 'to_alipay_dict'):
                params['org'] = self.org.to_alipay_dict()
            else:
                params['org'] = self.org
        if self.third_party_user_id:
            if hasattr(self.third_party_user_id, 'to_alipay_dict'):
                params['third_party_user_id'] = self.third_party_user_id.to_alipay_dict()
            else:
                params['third_party_user_id'] = self.third_party_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignerBean()
        if 'email' in d:
            o.email = d['email']
        if 'id_number' in d:
            o.id_number = d['id_number']
        if 'id_type' in d:
            o.id_type = d['id_type']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'org' in d:
            o.org = d['org']
        if 'third_party_user_id' in d:
            o.third_party_user_id = d['third_party_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AppxVersionConfigVo(object):

    def __init__(self):
        self._id = None
        self._proportion = None
        self._ver = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def proportion(self):
        return self._proportion

    @proportion.setter
    def proportion(self, value):
        self._proportion = value
    @property
    def ver(self):
        return self._ver

    @ver.setter
    def ver(self, value):
        self._ver = value


    def to_alipay_dict(self):
        params = dict()
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.proportion:
            if hasattr(self.proportion, 'to_alipay_dict'):
                params['proportion'] = self.proportion.to_alipay_dict()
            else:
                params['proportion'] = self.proportion
        if self.ver:
            if hasattr(self.ver, 'to_alipay_dict'):
                params['ver'] = self.ver.to_alipay_dict()
            else:
                params['ver'] = self.ver
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AppxVersionConfigVo()
        if 'id' in d:
            o.id = d['id']
        if 'proportion' in d:
            o.proportion = d['proportion']
        if 'ver' in d:
            o.ver = d['ver']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PhotoInfo(object):

    def __init__(self):
        self._img_height = None
        self._img_width = None
        self._name = None
        self._photo_size = None
        self._photo_url = None

    @property
    def img_height(self):
        return self._img_height

    @img_height.setter
    def img_height(self, value):
        self._img_height = value
    @property
    def img_width(self):
        return self._img_width

    @img_width.setter
    def img_width(self, value):
        self._img_width = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def photo_size(self):
        return self._photo_size

    @photo_size.setter
    def photo_size(self, value):
        self._photo_size = value
    @property
    def photo_url(self):
        return self._photo_url

    @photo_url.setter
    def photo_url(self, value):
        self._photo_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.img_height:
            if hasattr(self.img_height, 'to_alipay_dict'):
                params['img_height'] = self.img_height.to_alipay_dict()
            else:
                params['img_height'] = self.img_height
        if self.img_width:
            if hasattr(self.img_width, 'to_alipay_dict'):
                params['img_width'] = self.img_width.to_alipay_dict()
            else:
                params['img_width'] = self.img_width
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.photo_size:
            if hasattr(self.photo_size, 'to_alipay_dict'):
                params['photo_size'] = self.photo_size.to_alipay_dict()
            else:
                params['photo_size'] = self.photo_size
        if self.photo_url:
            if hasattr(self.photo_url, 'to_alipay_dict'):
                params['photo_url'] = self.photo_url.to_alipay_dict()
            else:
                params['photo_url'] = self.photo_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PhotoInfo()
        if 'img_height' in d:
            o.img_height = d['img_height']
        if 'img_width' in d:
            o.img_width = d['img_width']
        if 'name' in d:
            o.name = d['name']
        if 'photo_size' in d:
            o.photo_size = d['photo_size']
        if 'photo_url' in d:
            o.photo_url = d['photo_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateFacefeatureFileApplyModel(object):

    def __init__(self):
        self._biz_code = None
        self._feature_version = None
        self._file_date = None
        self._file_type = None
        self._institution_id = None
        self._isv_name = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def feature_version(self):
        return self._feature_version

    @feature_version.setter
    def feature_version(self, value):
        self._feature_version = value
    @property
    def file_date(self):
        return self._file_date

    @file_date.setter
    def file_date(self, value):
        self._file_date = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def institution_id(self):
        return self._institution_id

    @institution_id.setter
    def institution_id(self, value):
        self._institution_id = value
    @property
    def isv_name(self):
        return self._isv_name

    @isv_name.setter
    def isv_name(self, value):
        self._isv_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.feature_version:
            if hasattr(self.feature_version, 'to_alipay_dict'):
                params['feature_version'] = self.feature_version.to_alipay_dict()
            else:
                params['feature_version'] = self.feature_version
        if self.file_date:
            if hasattr(self.file_date, 'to_alipay_dict'):
                params['file_date'] = self.file_date.to_alipay_dict()
            else:
                params['file_date'] = self.file_date
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.institution_id:
            if hasattr(self.institution_id, 'to_alipay_dict'):
                params['institution_id'] = self.institution_id.to_alipay_dict()
            else:
                params['institution_id'] = self.institution_id
        if self.isv_name:
            if hasattr(self.isv_name, 'to_alipay_dict'):
                params['isv_name'] = self.isv_name.to_alipay_dict()
            else:
                params['isv_name'] = self.isv_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateFacefeatureFileApplyModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'feature_version' in d:
            o.feature_version = d['feature_version']
        if 'file_date' in d:
            o.file_date = d['file_date']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'institution_id' in d:
            o.institution_id = d['institution_id']
        if 'isv_name' in d:
            o.isv_name = d['isv_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderGoodsDTO(object):

    def __init__(self):
        self._goods_amount = None
        self._goods_effective_duration = None
        self._goods_id = None
        self._goods_name = None
        self._goods_prd_time = None
        self._item_id = None

    @property
    def goods_amount(self):
        return self._goods_amount

    @goods_amount.setter
    def goods_amount(self, value):
        self._goods_amount = value
    @property
    def goods_effective_duration(self):
        return self._goods_effective_duration

    @goods_effective_duration.setter
    def goods_effective_duration(self, value):
        self._goods_effective_duration = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def goods_prd_time(self):
        return self._goods_prd_time

    @goods_prd_time.setter
    def goods_prd_time(self, value):
        self._goods_prd_time = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_amount:
            if hasattr(self.goods_amount, 'to_alipay_dict'):
                params['goods_amount'] = self.goods_amount.to_alipay_dict()
            else:
                params['goods_amount'] = self.goods_amount
        if self.goods_effective_duration:
            if hasattr(self.goods_effective_duration, 'to_alipay_dict'):
                params['goods_effective_duration'] = self.goods_effective_duration.to_alipay_dict()
            else:
                params['goods_effective_duration'] = self.goods_effective_duration
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.goods_prd_time:
            if hasattr(self.goods_prd_time, 'to_alipay_dict'):
                params['goods_prd_time'] = self.goods_prd_time.to_alipay_dict()
            else:
                params['goods_prd_time'] = self.goods_prd_time
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderGoodsDTO()
        if 'goods_amount' in d:
            o.goods_amount = d['goods_amount']
        if 'goods_effective_duration' in d:
            o.goods_effective_duration = d['goods_effective_duration']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'goods_prd_time' in d:
            o.goods_prd_time = d['goods_prd_time']
        if 'item_id' in d:
            o.item_id = d['item_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataZbdmLineageQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataZbdmLineageQueryResponse, self).__init__()
        self._edges = None
        self._vertices = None

    @property
    def edges(self):
        return self._edges

    @edges.setter
    def edges(self, value):
        if isinstance(value, list):
            self._edges = list()
            for i in value:
                self._edges.append(i)
    @property
    def vertices(self):
        return self._vertices

    @vertices.setter
    def vertices(self, value):
        if isinstance(value, list):
            self._vertices = list()
            for i in value:
                self._vertices.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayDataZbdmLineageQueryResponse, self).parse_response_content(response_content)
        if 'edges' in response:
            self.edges = response['edges']
        if 'vertices' in response:
            self.vertices = response['vertices']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.WeatherInfo import WeatherInfo


class AnttechBlockchainDefinDataserviceWeatherinfosQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinDataserviceWeatherinfosQueryResponse, self).__init__()
        self._weather_infos = None

    @property
    def weather_infos(self):
        return self._weather_infos

    @weather_infos.setter
    def weather_infos(self, value):
        if isinstance(value, list):
            self._weather_infos = list()
            for i in value:
                if isinstance(i, WeatherInfo):
                    self._weather_infos.append(i)
                else:
                    self._weather_infos.append(WeatherInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinDataserviceWeatherinfosQueryResponse, self).parse_response_content(response_content)
        if 'weather_infos' in response:
            self.weather_infos = response['weather_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZolozIdentificationUserWebQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZolozIdentificationUserWebQueryResponse, self).__init__()
        self._extern_info = None

    @property
    def extern_info(self):
        return self._extern_info

    @extern_info.setter
    def extern_info(self, value):
        self._extern_info = value

    def parse_response_content(self, response_content):
        response = super(ZolozIdentificationUserWebQueryResponse, self).parse_response_content(response_content)
        if 'extern_info' in response:
            self.extern_info = response['extern_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditSupplychainArSignModel(object):

    def __init__(self):
        self._ar_pd_code = None
        self._request_id = None
        self._shop_id = None
        self._shop_name = None
        self._site = None
        self._site_user_id = None
        self._trade_source = None

    @property
    def ar_pd_code(self):
        return self._ar_pd_code

    @ar_pd_code.setter
    def ar_pd_code(self, value):
        self._ar_pd_code = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_user_id(self):
        return self._site_user_id

    @site_user_id.setter
    def site_user_id(self, value):
        self._site_user_id = value
    @property
    def trade_source(self):
        return self._trade_source

    @trade_source.setter
    def trade_source(self, value):
        self._trade_source = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_pd_code:
            if hasattr(self.ar_pd_code, 'to_alipay_dict'):
                params['ar_pd_code'] = self.ar_pd_code.to_alipay_dict()
            else:
                params['ar_pd_code'] = self.ar_pd_code
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.site_user_id:
            if hasattr(self.site_user_id, 'to_alipay_dict'):
                params['site_user_id'] = self.site_user_id.to_alipay_dict()
            else:
                params['site_user_id'] = self.site_user_id
        if self.trade_source:
            if hasattr(self.trade_source, 'to_alipay_dict'):
                params['trade_source'] = self.trade_source.to_alipay_dict()
            else:
                params['trade_source'] = self.trade_source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainArSignModel()
        if 'ar_pd_code' in d:
            o.ar_pd_code = d['ar_pd_code']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'site' in d:
            o.site = d['site']
        if 'site_user_id' in d:
            o.site_user_id = d['site_user_id']
        if 'trade_source' in d:
            o.trade_source = d['trade_source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ViewStyleInfoModel(object):

    def __init__(self):
        self._bg_color = None
        self._bg_img = None
        self._brand_name = None
        self._logo_img = None

    @property
    def bg_color(self):
        return self._bg_color

    @bg_color.setter
    def bg_color(self, value):
        self._bg_color = value
    @property
    def bg_img(self):
        return self._bg_img

    @bg_img.setter
    def bg_img(self, value):
        self._bg_img = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def logo_img(self):
        return self._logo_img

    @logo_img.setter
    def logo_img(self, value):
        self._logo_img = value


    def to_alipay_dict(self):
        params = dict()
        if self.bg_color:
            if hasattr(self.bg_color, 'to_alipay_dict'):
                params['bg_color'] = self.bg_color.to_alipay_dict()
            else:
                params['bg_color'] = self.bg_color
        if self.bg_img:
            if hasattr(self.bg_img, 'to_alipay_dict'):
                params['bg_img'] = self.bg_img.to_alipay_dict()
            else:
                params['bg_img'] = self.bg_img
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.logo_img:
            if hasattr(self.logo_img, 'to_alipay_dict'):
                params['logo_img'] = self.logo_img.to_alipay_dict()
            else:
                params['logo_img'] = self.logo_img
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ViewStyleInfoModel()
        if 'bg_color' in d:
            o.bg_color = d['bg_color']
        if 'bg_img' in d:
            o.bg_img = d['bg_img']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'logo_img' in d:
            o.logo_img = d['logo_img']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CfbudmacBizActionConsumedAmountDTO(object):

    def __init__(self):
        self._biz_budget_apply_code = None
        self._biz_uk_id = None
        self._consumed_amount = None
        self._consumed_amount_currency = None

    @property
    def biz_budget_apply_code(self):
        return self._biz_budget_apply_code

    @biz_budget_apply_code.setter
    def biz_budget_apply_code(self, value):
        self._biz_budget_apply_code = value
    @property
    def biz_uk_id(self):
        return self._biz_uk_id

    @biz_uk_id.setter
    def biz_uk_id(self, value):
        self._biz_uk_id = value
    @property
    def consumed_amount(self):
        return self._consumed_amount

    @consumed_amount.setter
    def consumed_amount(self, value):
        self._consumed_amount = value
    @property
    def consumed_amount_currency(self):
        return self._consumed_amount_currency

    @consumed_amount_currency.setter
    def consumed_amount_currency(self, value):
        self._consumed_amount_currency = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_budget_apply_code:
            if hasattr(self.biz_budget_apply_code, 'to_alipay_dict'):
                params['biz_budget_apply_code'] = self.biz_budget_apply_code.to_alipay_dict()
            else:
                params['biz_budget_apply_code'] = self.biz_budget_apply_code
        if self.biz_uk_id:
            if hasattr(self.biz_uk_id, 'to_alipay_dict'):
                params['biz_uk_id'] = self.biz_uk_id.to_alipay_dict()
            else:
                params['biz_uk_id'] = self.biz_uk_id
        if self.consumed_amount:
            if hasattr(self.consumed_amount, 'to_alipay_dict'):
                params['consumed_amount'] = self.consumed_amount.to_alipay_dict()
            else:
                params['consumed_amount'] = self.consumed_amount
        if self.consumed_amount_currency:
            if hasattr(self.consumed_amount_currency, 'to_alipay_dict'):
                params['consumed_amount_currency'] = self.consumed_amount_currency.to_alipay_dict()
            else:
                params['consumed_amount_currency'] = self.consumed_amount_currency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CfbudmacBizActionConsumedAmountDTO()
        if 'biz_budget_apply_code' in d:
            o.biz_budget_apply_code = d['biz_budget_apply_code']
        if 'biz_uk_id' in d:
            o.biz_uk_id = d['biz_uk_id']
        if 'consumed_amount' in d:
            o.consumed_amount = d['consumed_amount']
        if 'consumed_amount_currency' in d:
            o.consumed_amount_currency = d['consumed_amount_currency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SignRecordLogVO import SignRecordLogVO


class SignRecordVO(object):

    def __init__(self):
        self._agreement_id = None
        self._log_vos = None
        self._out_sign_no = None
        self._product_cd = None
        self._status = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def log_vos(self):
        return self._log_vos

    @log_vos.setter
    def log_vos(self, value):
        if isinstance(value, list):
            self._log_vos = list()
            for i in value:
                if isinstance(i, SignRecordLogVO):
                    self._log_vos.append(i)
                else:
                    self._log_vos.append(SignRecordLogVO.from_alipay_dict(i))
    @property
    def out_sign_no(self):
        return self._out_sign_no

    @out_sign_no.setter
    def out_sign_no(self, value):
        self._out_sign_no = value
    @property
    def product_cd(self):
        return self._product_cd

    @product_cd.setter
    def product_cd(self, value):
        self._product_cd = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.log_vos:
            if isinstance(self.log_vos, list):
                for i in range(0, len(self.log_vos)):
                    element = self.log_vos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.log_vos[i] = element.to_alipay_dict()
            if hasattr(self.log_vos, 'to_alipay_dict'):
                params['log_vos'] = self.log_vos.to_alipay_dict()
            else:
                params['log_vos'] = self.log_vos
        if self.out_sign_no:
            if hasattr(self.out_sign_no, 'to_alipay_dict'):
                params['out_sign_no'] = self.out_sign_no.to_alipay_dict()
            else:
                params['out_sign_no'] = self.out_sign_no
        if self.product_cd:
            if hasattr(self.product_cd, 'to_alipay_dict'):
                params['product_cd'] = self.product_cd.to_alipay_dict()
            else:
                params['product_cd'] = self.product_cd
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignRecordVO()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'log_vos' in d:
            o.log_vos = d['log_vos']
        if 'out_sign_no' in d:
            o.out_sign_no = d['out_sign_no']
        if 'product_cd' in d:
            o.product_cd = d['product_cd']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TenantChannelDetailDTO(object):

    def __init__(self):
        self._channel_code = None
        self._channel_desc = None
        self._channel_id = None
        self._channel_name = None
        self._channel_status = None
        self._channel_type = None
        self._form_template_id = None
        self._pic_url = None
        self._remark = None
        self._status = None
        self._tenant_code = None

    @property
    def channel_code(self):
        return self._channel_code

    @channel_code.setter
    def channel_code(self, value):
        self._channel_code = value
    @property
    def channel_desc(self):
        return self._channel_desc

    @channel_desc.setter
    def channel_desc(self, value):
        self._channel_desc = value
    @property
    def channel_id(self):
        return self._channel_id

    @channel_id.setter
    def channel_id(self, value):
        self._channel_id = value
    @property
    def channel_name(self):
        return self._channel_name

    @channel_name.setter
    def channel_name(self, value):
        self._channel_name = value
    @property
    def channel_status(self):
        return self._channel_status

    @channel_status.setter
    def channel_status(self, value):
        self._channel_status = value
    @property
    def channel_type(self):
        return self._channel_type

    @channel_type.setter
    def channel_type(self, value):
        self._channel_type = value
    @property
    def form_template_id(self):
        return self._form_template_id

    @form_template_id.setter
    def form_template_id(self, value):
        self._form_template_id = value
    @property
    def pic_url(self):
        return self._pic_url

    @pic_url.setter
    def pic_url(self, value):
        self._pic_url = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_code:
            if hasattr(self.channel_code, 'to_alipay_dict'):
                params['channel_code'] = self.channel_code.to_alipay_dict()
            else:
                params['channel_code'] = self.channel_code
        if self.channel_desc:
            if hasattr(self.channel_desc, 'to_alipay_dict'):
                params['channel_desc'] = self.channel_desc.to_alipay_dict()
            else:
                params['channel_desc'] = self.channel_desc
        if self.channel_id:
            if hasattr(self.channel_id, 'to_alipay_dict'):
                params['channel_id'] = self.channel_id.to_alipay_dict()
            else:
                params['channel_id'] = self.channel_id
        if self.channel_name:
            if hasattr(self.channel_name, 'to_alipay_dict'):
                params['channel_name'] = self.channel_name.to_alipay_dict()
            else:
                params['channel_name'] = self.channel_name
        if self.channel_status:
            if hasattr(self.channel_status, 'to_alipay_dict'):
                params['channel_status'] = self.channel_status.to_alipay_dict()
            else:
                params['channel_status'] = self.channel_status
        if self.channel_type:
            if hasattr(self.channel_type, 'to_alipay_dict'):
                params['channel_type'] = self.channel_type.to_alipay_dict()
            else:
                params['channel_type'] = self.channel_type
        if self.form_template_id:
            if hasattr(self.form_template_id, 'to_alipay_dict'):
                params['form_template_id'] = self.form_template_id.to_alipay_dict()
            else:
                params['form_template_id'] = self.form_template_id
        if self.pic_url:
            if hasattr(self.pic_url, 'to_alipay_dict'):
                params['pic_url'] = self.pic_url.to_alipay_dict()
            else:
                params['pic_url'] = self.pic_url
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TenantChannelDetailDTO()
        if 'channel_code' in d:
            o.channel_code = d['channel_code']
        if 'channel_desc' in d:
            o.channel_desc = d['channel_desc']
        if 'channel_id' in d:
            o.channel_id = d['channel_id']
        if 'channel_name' in d:
            o.channel_name = d['channel_name']
        if 'channel_status' in d:
            o.channel_status = d['channel_status']
        if 'channel_type' in d:
            o.channel_type = d['channel_type']
        if 'form_template_id' in d:
            o.form_template_id = d['form_template_id']
        if 'pic_url' in d:
            o.pic_url = d['pic_url']
        if 'remark' in d:
            o.remark = d['remark']
        if 'status' in d:
            o.status = d['status']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ChatMessage(object):

    def __init__(self):
        self._message_content = None
        self._message_type = None
        self._send_time = None
        self._user_name = None
        self._user_type = None

    @property
    def message_content(self):
        return self._message_content

    @message_content.setter
    def message_content(self, value):
        self._message_content = value
    @property
    def message_type(self):
        return self._message_type

    @message_type.setter
    def message_type(self, value):
        self._message_type = value
    @property
    def send_time(self):
        return self._send_time

    @send_time.setter
    def send_time(self, value):
        self._send_time = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.message_content:
            if hasattr(self.message_content, 'to_alipay_dict'):
                params['message_content'] = self.message_content.to_alipay_dict()
            else:
                params['message_content'] = self.message_content
        if self.message_type:
            if hasattr(self.message_type, 'to_alipay_dict'):
                params['message_type'] = self.message_type.to_alipay_dict()
            else:
                params['message_type'] = self.message_type
        if self.send_time:
            if hasattr(self.send_time, 'to_alipay_dict'):
                params['send_time'] = self.send_time.to_alipay_dict()
            else:
                params['send_time'] = self.send_time
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        if self.user_type:
            if hasattr(self.user_type, 'to_alipay_dict'):
                params['user_type'] = self.user_type.to_alipay_dict()
            else:
                params['user_type'] = self.user_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ChatMessage()
        if 'message_content' in d:
            o.message_content = d['message_content']
        if 'message_type' in d:
            o.message_type = d['message_type']
        if 'send_time' in d:
            o.send_time = d['send_time']
        if 'user_name' in d:
            o.user_name = d['user_name']
        if 'user_type' in d:
            o.user_type = d['user_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseContentlibStandardcontentSendModel(object):

    def __init__(self):
        self._action_type = None
        self._ext_info = None
        self._public_id = None
        self._source_author = None
        self._source_category = None
        self._source_content = None
        self._source_cover = None
        self._source_id = None
        self._source_keywords = None
        self._source_link = None
        self._source_publish_date = None
        self._source_summary = None
        self._source_thumbnail_type = None
        self._source_thumbnails = None
        self._source_title = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value
    @property
    def source_author(self):
        return self._source_author

    @source_author.setter
    def source_author(self, value):
        self._source_author = value
    @property
    def source_category(self):
        return self._source_category

    @source_category.setter
    def source_category(self, value):
        self._source_category = value
    @property
    def source_content(self):
        return self._source_content

    @source_content.setter
    def source_content(self, value):
        self._source_content = value
    @property
    def source_cover(self):
        return self._source_cover

    @source_cover.setter
    def source_cover(self, value):
        self._source_cover = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value
    @property
    def source_keywords(self):
        return self._source_keywords

    @source_keywords.setter
    def source_keywords(self, value):
        self._source_keywords = value
    @property
    def source_link(self):
        return self._source_link

    @source_link.setter
    def source_link(self, value):
        self._source_link = value
    @property
    def source_publish_date(self):
        return self._source_publish_date

    @source_publish_date.setter
    def source_publish_date(self, value):
        self._source_publish_date = value
    @property
    def source_summary(self):
        return self._source_summary

    @source_summary.setter
    def source_summary(self, value):
        self._source_summary = value
    @property
    def source_thumbnail_type(self):
        return self._source_thumbnail_type

    @source_thumbnail_type.setter
    def source_thumbnail_type(self, value):
        self._source_thumbnail_type = value
    @property
    def source_thumbnails(self):
        return self._source_thumbnails

    @source_thumbnails.setter
    def source_thumbnails(self, value):
        self._source_thumbnails = value
    @property
    def source_title(self):
        return self._source_title

    @source_title.setter
    def source_title(self, value):
        self._source_title = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.public_id:
            if hasattr(self.public_id, 'to_alipay_dict'):
                params['public_id'] = self.public_id.to_alipay_dict()
            else:
                params['public_id'] = self.public_id
        if self.source_author:
            if hasattr(self.source_author, 'to_alipay_dict'):
                params['source_author'] = self.source_author.to_alipay_dict()
            else:
                params['source_author'] = self.source_author
        if self.source_category:
            if hasattr(self.source_category, 'to_alipay_dict'):
                params['source_category'] = self.source_category.to_alipay_dict()
            else:
                params['source_category'] = self.source_category
        if self.source_content:
            if hasattr(self.source_content, 'to_alipay_dict'):
                params['source_content'] = self.source_content.to_alipay_dict()
            else:
                params['source_content'] = self.source_content
        if self.source_cover:
            if hasattr(self.source_cover, 'to_alipay_dict'):
                params['source_cover'] = self.source_cover.to_alipay_dict()
            else:
                params['source_cover'] = self.source_cover
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        if self.source_keywords:
            if hasattr(self.source_keywords, 'to_alipay_dict'):
                params['source_keywords'] = self.source_keywords.to_alipay_dict()
            else:
                params['source_keywords'] = self.source_keywords
        if self.source_link:
            if hasattr(self.source_link, 'to_alipay_dict'):
                params['source_link'] = self.source_link.to_alipay_dict()
            else:
                params['source_link'] = self.source_link
        if self.source_publish_date:
            if hasattr(self.source_publish_date, 'to_alipay_dict'):
                params['source_publish_date'] = self.source_publish_date.to_alipay_dict()
            else:
                params['source_publish_date'] = self.source_publish_date
        if self.source_summary:
            if hasattr(self.source_summary, 'to_alipay_dict'):
                params['source_summary'] = self.source_summary.to_alipay_dict()
            else:
                params['source_summary'] = self.source_summary
        if self.source_thumbnail_type:
            if hasattr(self.source_thumbnail_type, 'to_alipay_dict'):
                params['source_thumbnail_type'] = self.source_thumbnail_type.to_alipay_dict()
            else:
                params['source_thumbnail_type'] = self.source_thumbnail_type
        if self.source_thumbnails:
            if hasattr(self.source_thumbnails, 'to_alipay_dict'):
                params['source_thumbnails'] = self.source_thumbnails.to_alipay_dict()
            else:
                params['source_thumbnails'] = self.source_thumbnails
        if self.source_title:
            if hasattr(self.source_title, 'to_alipay_dict'):
                params['source_title'] = self.source_title.to_alipay_dict()
            else:
                params['source_title'] = self.source_title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseContentlibStandardcontentSendModel()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'public_id' in d:
            o.public_id = d['public_id']
        if 'source_author' in d:
            o.source_author = d['source_author']
        if 'source_category' in d:
            o.source_category = d['source_category']
        if 'source_content' in d:
            o.source_content = d['source_content']
        if 'source_cover' in d:
            o.source_cover = d['source_cover']
        if 'source_id' in d:
            o.source_id = d['source_id']
        if 'source_keywords' in d:
            o.source_keywords = d['source_keywords']
        if 'source_link' in d:
            o.source_link = d['source_link']
        if 'source_publish_date' in d:
            o.source_publish_date = d['source_publish_date']
        if 'source_summary' in d:
            o.source_summary = d['source_summary']
        if 'source_thumbnail_type' in d:
            o.source_thumbnail_type = d['source_thumbnail_type']
        if 'source_thumbnails' in d:
            o.source_thumbnails = d['source_thumbnails']
        if 'source_title' in d:
            o.source_title = d['source_title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishBaseActivityInfo import KbdishBaseActivityInfo
from alipay.aop.api.domain.KbdishGroupSimplifyInfo import KbdishGroupSimplifyInfo
from alipay.aop.api.domain.KbdishMaterialSimplifyInfo import KbdishMaterialSimplifyInfo
from alipay.aop.api.domain.KbdishPeriodExtendInfo import KbdishPeriodExtendInfo
from alipay.aop.api.domain.KbdishPropertySimplifyInfo import KbdishPropertySimplifyInfo
from alipay.aop.api.domain.KbdishSkuSimplifyInfo import KbdishSkuSimplifyInfo


class KoubeiCateringDishCreatedishSyncModel(object):

    def __init__(self):
        self._activity_info = None
        self._catetory_name = None
        self._catetory_sort = None
        self._dish_background_img = None
        self._dish_detail_img_list = None
        self._dmg_img = None
        self._group_list = None
        self._material_group_list = None
        self._min_serving = None
        self._name = None
        self._non_whole_order_discount = None
        self._out_dish_id = None
        self._out_shop_id = None
        self._period = None
        self._property_list = None
        self._remarks = None
        self._shop_id = None
        self._sku_list = None
        self._status = None
        self._sub_name = None
        self._tags = None
        self._type_big = None
        self._type_sub = None
        self._unit = None

    @property
    def activity_info(self):
        return self._activity_info

    @activity_info.setter
    def activity_info(self, value):
        if isinstance(value, KbdishBaseActivityInfo):
            self._activity_info = value
        else:
            self._activity_info = KbdishBaseActivityInfo.from_alipay_dict(value)
    @property
    def catetory_name(self):
        return self._catetory_name

    @catetory_name.setter
    def catetory_name(self, value):
        self._catetory_name = value
    @property
    def catetory_sort(self):
        return self._catetory_sort

    @catetory_sort.setter
    def catetory_sort(self, value):
        self._catetory_sort = value
    @property
    def dish_background_img(self):
        return self._dish_background_img

    @dish_background_img.setter
    def dish_background_img(self, value):
        self._dish_background_img = value
    @property
    def dish_detail_img_list(self):
        return self._dish_detail_img_list

    @dish_detail_img_list.setter
    def dish_detail_img_list(self, value):
        if isinstance(value, list):
            self._dish_detail_img_list = list()
            for i in value:
                self._dish_detail_img_list.append(i)
    @property
    def dmg_img(self):
        return self._dmg_img

    @dmg_img.setter
    def dmg_img(self, value):
        self._dmg_img = value
    @property
    def group_list(self):
        return self._group_list

    @group_list.setter
    def group_list(self, value):
        if isinstance(value, list):
            self._group_list = list()
            for i in value:
                if isinstance(i, KbdishGroupSimplifyInfo):
                    self._group_list.append(i)
                else:
                    self._group_list.append(KbdishGroupSimplifyInfo.from_alipay_dict(i))
    @property
    def material_group_list(self):
        return self._material_group_list

    @material_group_list.setter
    def material_group_list(self, value):
        if isinstance(value, list):
            self._material_group_list = list()
            for i in value:
                if isinstance(i, KbdishMaterialSimplifyInfo):
                    self._material_group_list.append(i)
                else:
                    self._material_group_list.append(KbdishMaterialSimplifyInfo.from_alipay_dict(i))
    @property
    def min_serving(self):
        return self._min_serving

    @min_serving.setter
    def min_serving(self, value):
        self._min_serving = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def non_whole_order_discount(self):
        return self._non_whole_order_discount

    @non_whole_order_discount.setter
    def non_whole_order_discount(self, value):
        self._non_whole_order_discount = value
    @property
    def out_dish_id(self):
        return self._out_dish_id

    @out_dish_id.setter
    def out_dish_id(self, value):
        self._out_dish_id = value
    @property
    def out_shop_id(self):
        return self._out_shop_id

    @out_shop_id.setter
    def out_shop_id(self, value):
        self._out_shop_id = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        if isinstance(value, KbdishPeriodExtendInfo):
            self._period = value
        else:
            self._period = KbdishPeriodExtendInfo.from_alipay_dict(value)
    @property
    def property_list(self):
        return self._property_list

    @property_list.setter
    def property_list(self, value):
        if isinstance(value, list):
            self._property_list = list()
            for i in value:
                if isinstance(i, KbdishPropertySimplifyInfo):
                    self._property_list.append(i)
                else:
                    self._property_list.append(KbdishPropertySimplifyInfo.from_alipay_dict(i))
    @property
    def remarks(self):
        return self._remarks

    @remarks.setter
    def remarks(self, value):
        self._remarks = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def sku_list(self):
        return self._sku_list

    @sku_list.setter
    def sku_list(self, value):
        if isinstance(value, list):
            self._sku_list = list()
            for i in value:
                if isinstance(i, KbdishSkuSimplifyInfo):
                    self._sku_list.append(i)
                else:
                    self._sku_list.append(KbdishSkuSimplifyInfo.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_name(self):
        return self._sub_name

    @sub_name.setter
    def sub_name(self, value):
        self._sub_name = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def type_big(self):
        return self._type_big

    @type_big.setter
    def type_big(self, value):
        self._type_big = value
    @property
    def type_sub(self):
        return self._type_sub

    @type_sub.setter
    def type_sub(self, value):
        self._type_sub = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_info:
            if hasattr(self.activity_info, 'to_alipay_dict'):
                params['activity_info'] = self.activity_info.to_alipay_dict()
            else:
                params['activity_info'] = self.activity_info
        if self.catetory_name:
            if hasattr(self.catetory_name, 'to_alipay_dict'):
                params['catetory_name'] = self.catetory_name.to_alipay_dict()
            else:
                params['catetory_name'] = self.catetory_name
        if self.catetory_sort:
            if hasattr(self.catetory_sort, 'to_alipay_dict'):
                params['catetory_sort'] = self.catetory_sort.to_alipay_dict()
            else:
                params['catetory_sort'] = self.catetory_sort
        if self.dish_background_img:
            if hasattr(self.dish_background_img, 'to_alipay_dict'):
                params['dish_background_img'] = self.dish_background_img.to_alipay_dict()
            else:
                params['dish_background_img'] = self.dish_background_img
        if self.dish_detail_img_list:
            if isinstance(self.dish_detail_img_list, list):
                for i in range(0, len(self.dish_detail_img_list)):
                    element = self.dish_detail_img_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_detail_img_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_detail_img_list, 'to_alipay_dict'):
                params['dish_detail_img_list'] = self.dish_detail_img_list.to_alipay_dict()
            else:
                params['dish_detail_img_list'] = self.dish_detail_img_list
        if self.dmg_img:
            if hasattr(self.dmg_img, 'to_alipay_dict'):
                params['dmg_img'] = self.dmg_img.to_alipay_dict()
            else:
                params['dmg_img'] = self.dmg_img
        if self.group_list:
            if isinstance(self.group_list, list):
                for i in range(0, len(self.group_list)):
                    element = self.group_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.group_list[i] = element.to_alipay_dict()
            if hasattr(self.group_list, 'to_alipay_dict'):
                params['group_list'] = self.group_list.to_alipay_dict()
            else:
                params['group_list'] = self.group_list
        if self.material_group_list:
            if isinstance(self.material_group_list, list):
                for i in range(0, len(self.material_group_list)):
                    element = self.material_group_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.material_group_list[i] = element.to_alipay_dict()
            if hasattr(self.material_group_list, 'to_alipay_dict'):
                params['material_group_list'] = self.material_group_list.to_alipay_dict()
            else:
                params['material_group_list'] = self.material_group_list
        if self.min_serving:
            if hasattr(self.min_serving, 'to_alipay_dict'):
                params['min_serving'] = self.min_serving.to_alipay_dict()
            else:
                params['min_serving'] = self.min_serving
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.non_whole_order_discount:
            if hasattr(self.non_whole_order_discount, 'to_alipay_dict'):
                params['non_whole_order_discount'] = self.non_whole_order_discount.to_alipay_dict()
            else:
                params['non_whole_order_discount'] = self.non_whole_order_discount
        if self.out_dish_id:
            if hasattr(self.out_dish_id, 'to_alipay_dict'):
                params['out_dish_id'] = self.out_dish_id.to_alipay_dict()
            else:
                params['out_dish_id'] = self.out_dish_id
        if self.out_shop_id:
            if hasattr(self.out_shop_id, 'to_alipay_dict'):
                params['out_shop_id'] = self.out_shop_id.to_alipay_dict()
            else:
                params['out_shop_id'] = self.out_shop_id
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.property_list:
            if isinstance(self.property_list, list):
                for i in range(0, len(self.property_list)):
                    element = self.property_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.property_list[i] = element.to_alipay_dict()
            if hasattr(self.property_list, 'to_alipay_dict'):
                params['property_list'] = self.property_list.to_alipay_dict()
            else:
                params['property_list'] = self.property_list
        if self.remarks:
            if hasattr(self.remarks, 'to_alipay_dict'):
                params['remarks'] = self.remarks.to_alipay_dict()
            else:
                params['remarks'] = self.remarks
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.sku_list:
            if isinstance(self.sku_list, list):
                for i in range(0, len(self.sku_list)):
                    element = self.sku_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sku_list[i] = element.to_alipay_dict()
            if hasattr(self.sku_list, 'to_alipay_dict'):
                params['sku_list'] = self.sku_list.to_alipay_dict()
            else:
                params['sku_list'] = self.sku_list
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_name:
            if hasattr(self.sub_name, 'to_alipay_dict'):
                params['sub_name'] = self.sub_name.to_alipay_dict()
            else:
                params['sub_name'] = self.sub_name
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.type_big:
            if hasattr(self.type_big, 'to_alipay_dict'):
                params['type_big'] = self.type_big.to_alipay_dict()
            else:
                params['type_big'] = self.type_big
        if self.type_sub:
            if hasattr(self.type_sub, 'to_alipay_dict'):
                params['type_sub'] = self.type_sub.to_alipay_dict()
            else:
                params['type_sub'] = self.type_sub
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishCreatedishSyncModel()
        if 'activity_info' in d:
            o.activity_info = d['activity_info']
        if 'catetory_name' in d:
            o.catetory_name = d['catetory_name']
        if 'catetory_sort' in d:
            o.catetory_sort = d['catetory_sort']
        if 'dish_background_img' in d:
            o.dish_background_img = d['dish_background_img']
        if 'dish_detail_img_list' in d:
            o.dish_detail_img_list = d['dish_detail_img_list']
        if 'dmg_img' in d:
            o.dmg_img = d['dmg_img']
        if 'group_list' in d:
            o.group_list = d['group_list']
        if 'material_group_list' in d:
            o.material_group_list = d['material_group_list']
        if 'min_serving' in d:
            o.min_serving = d['min_serving']
        if 'name' in d:
            o.name = d['name']
        if 'non_whole_order_discount' in d:
            o.non_whole_order_discount = d['non_whole_order_discount']
        if 'out_dish_id' in d:
            o.out_dish_id = d['out_dish_id']
        if 'out_shop_id' in d:
            o.out_shop_id = d['out_shop_id']
        if 'period' in d:
            o.period = d['period']
        if 'property_list' in d:
            o.property_list = d['property_list']
        if 'remarks' in d:
            o.remarks = d['remarks']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'sku_list' in d:
            o.sku_list = d['sku_list']
        if 'status' in d:
            o.status = d['status']
        if 'sub_name' in d:
            o.sub_name = d['sub_name']
        if 'tags' in d:
            o.tags = d['tags']
        if 'type_big' in d:
            o.type_big = d['type_big']
        if 'type_sub' in d:
            o.type_sub = d['type_sub']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCharityWithholdCreateModel(object):

    def __init__(self):
        self._biz_id = None
        self._donate_amount = None
        self._ext_info = None
        self._open_id = None
        self._out_biz_no = None
        self._product_code = None
        self._project_id = None
        self._user_id = None
        self._withhold_pid = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def donate_amount(self):
        return self._donate_amount

    @donate_amount.setter
    def donate_amount(self, value):
        self._donate_amount = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def withhold_pid(self):
        return self._withhold_pid

    @withhold_pid.setter
    def withhold_pid(self, value):
        self._withhold_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.donate_amount:
            if hasattr(self.donate_amount, 'to_alipay_dict'):
                params['donate_amount'] = self.donate_amount.to_alipay_dict()
            else:
                params['donate_amount'] = self.donate_amount
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.withhold_pid:
            if hasattr(self.withhold_pid, 'to_alipay_dict'):
                params['withhold_pid'] = self.withhold_pid.to_alipay_dict()
            else:
                params['withhold_pid'] = self.withhold_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCharityWithholdCreateModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'donate_amount' in d:
            o.donate_amount = d['donate_amount']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'project_id' in d:
            o.project_id = d['project_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'withhold_pid' in d:
            o.withhold_pid = d['withhold_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RetailItem(object):

    def __init__(self):
        self._available_times = None
        self._brand = None
        self._buy_url = None
        self._cate = None
        self._cate_cnt = None
        self._content = None
        self._detail_url = None
        self._goods_id = None
        self._id = None
        self._ip_role_id = None
        self._mini_app_id = None
        self._pic_url_list = None
        self._promo_pic_url_list = None
        self._shop_id = None
        self._status = None
        self._tags = None
        self._title = None

    @property
    def available_times(self):
        return self._available_times

    @available_times.setter
    def available_times(self, value):
        if isinstance(value, list):
            self._available_times = list()
            for i in value:
                self._available_times.append(i)
    @property
    def brand(self):
        return self._brand

    @brand.setter
    def brand(self, value):
        self._brand = value
    @property
    def buy_url(self):
        return self._buy_url

    @buy_url.setter
    def buy_url(self, value):
        self._buy_url = value
    @property
    def cate(self):
        return self._cate

    @cate.setter
    def cate(self, value):
        self._cate = value
    @property
    def cate_cnt(self):
        return self._cate_cnt

    @cate_cnt.setter
    def cate_cnt(self, value):
        self._cate_cnt = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def detail_url(self):
        return self._detail_url

    @detail_url.setter
    def detail_url(self, value):
        self._detail_url = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def pic_url_list(self):
        return self._pic_url_list

    @pic_url_list.setter
    def pic_url_list(self, value):
        if isinstance(value, list):
            self._pic_url_list = list()
            for i in value:
                self._pic_url_list.append(i)
    @property
    def promo_pic_url_list(self):
        return self._promo_pic_url_list

    @promo_pic_url_list.setter
    def promo_pic_url_list(self, value):
        if isinstance(value, list):
            self._promo_pic_url_list = list()
            for i in value:
                self._promo_pic_url_list.append(i)
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_times:
            if isinstance(self.available_times, list):
                for i in range(0, len(self.available_times)):
                    element = self.available_times[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_times[i] = element.to_alipay_dict()
            if hasattr(self.available_times, 'to_alipay_dict'):
                params['available_times'] = self.available_times.to_alipay_dict()
            else:
                params['available_times'] = self.available_times
        if self.brand:
            if hasattr(self.brand, 'to_alipay_dict'):
                params['brand'] = self.brand.to_alipay_dict()
            else:
                params['brand'] = self.brand
        if self.buy_url:
            if hasattr(self.buy_url, 'to_alipay_dict'):
                params['buy_url'] = self.buy_url.to_alipay_dict()
            else:
                params['buy_url'] = self.buy_url
        if self.cate:
            if hasattr(self.cate, 'to_alipay_dict'):
                params['cate'] = self.cate.to_alipay_dict()
            else:
                params['cate'] = self.cate
        if self.cate_cnt:
            if hasattr(self.cate_cnt, 'to_alipay_dict'):
                params['cate_cnt'] = self.cate_cnt.to_alipay_dict()
            else:
                params['cate_cnt'] = self.cate_cnt
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.detail_url:
            if hasattr(self.detail_url, 'to_alipay_dict'):
                params['detail_url'] = self.detail_url.to_alipay_dict()
            else:
                params['detail_url'] = self.detail_url
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.pic_url_list:
            if isinstance(self.pic_url_list, list):
                for i in range(0, len(self.pic_url_list)):
                    element = self.pic_url_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pic_url_list[i] = element.to_alipay_dict()
            if hasattr(self.pic_url_list, 'to_alipay_dict'):
                params['pic_url_list'] = self.pic_url_list.to_alipay_dict()
            else:
                params['pic_url_list'] = self.pic_url_list
        if self.promo_pic_url_list:
            if isinstance(self.promo_pic_url_list, list):
                for i in range(0, len(self.promo_pic_url_list)):
                    element = self.promo_pic_url_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.promo_pic_url_list[i] = element.to_alipay_dict()
            if hasattr(self.promo_pic_url_list, 'to_alipay_dict'):
                params['promo_pic_url_list'] = self.promo_pic_url_list.to_alipay_dict()
            else:
                params['promo_pic_url_list'] = self.promo_pic_url_list
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RetailItem()
        if 'available_times' in d:
            o.available_times = d['available_times']
        if 'brand' in d:
            o.brand = d['brand']
        if 'buy_url' in d:
            o.buy_url = d['buy_url']
        if 'cate' in d:
            o.cate = d['cate']
        if 'cate_cnt' in d:
            o.cate_cnt = d['cate_cnt']
        if 'content' in d:
            o.content = d['content']
        if 'detail_url' in d:
            o.detail_url = d['detail_url']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'id' in d:
            o.id = d['id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'pic_url_list' in d:
            o.pic_url_list = d['pic_url_list']
        if 'promo_pic_url_list' in d:
            o.promo_pic_url_list = d['promo_pic_url_list']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'status' in d:
            o.status = d['status']
        if 'tags' in d:
            o.tags = d['tags']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SubOrderInfo import SubOrderInfo


class AlipayEbppBillchargeOrderBatchcreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppBillchargeOrderBatchcreateResponse, self).__init__()
        self._open_id = None
        self._order_no = None
        self._out_biz_id = None
        self._status = None
        self._sub_order_list = None
        self._total_pay_amount = None
        self._user_id = None

    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_order_list(self):
        return self._sub_order_list

    @sub_order_list.setter
    def sub_order_list(self, value):
        if isinstance(value, list):
            self._sub_order_list = list()
            for i in value:
                if isinstance(i, SubOrderInfo):
                    self._sub_order_list.append(i)
                else:
                    self._sub_order_list.append(SubOrderInfo.from_alipay_dict(i))
    @property
    def total_pay_amount(self):
        return self._total_pay_amount

    @total_pay_amount.setter
    def total_pay_amount(self, value):
        self._total_pay_amount = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppBillchargeOrderBatchcreateResponse, self).parse_response_content(response_content)
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'out_biz_id' in response:
            self.out_biz_id = response['out_biz_id']
        if 'status' in response:
            self.status = response['status']
        if 'sub_order_list' in response:
            self.sub_order_list = response['sub_order_list']
        if 'total_pay_amount' in response:
            self.total_pay_amount = response['total_pay_amount']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniDataSummaryQueryModel(object):

    def __init__(self):
        self._report_date = None

    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniDataSummaryQueryModel()
        if 'report_date' in d:
            o.report_date = d['report_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceDeviceinstanceOnlineModel(object):

    def __init__(self):
        self._biz_token = None
        self._device_instance_id = None

    @property
    def biz_token(self):
        return self._biz_token

    @biz_token.setter
    def biz_token(self, value):
        self._biz_token = value
    @property
    def device_instance_id(self):
        return self._device_instance_id

    @device_instance_id.setter
    def device_instance_id(self, value):
        self._device_instance_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_token:
            if hasattr(self.biz_token, 'to_alipay_dict'):
                params['biz_token'] = self.biz_token.to_alipay_dict()
            else:
                params['biz_token'] = self.biz_token
        if self.device_instance_id:
            if hasattr(self.device_instance_id, 'to_alipay_dict'):
                params['device_instance_id'] = self.device_instance_id.to_alipay_dict()
            else:
                params['device_instance_id'] = self.device_instance_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceDeviceinstanceOnlineModel()
        if 'biz_token' in d:
            o.biz_token = d['biz_token']
        if 'device_instance_id' in d:
            o.device_instance_id = d['device_instance_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AlipayItemVoucherTemplete import AlipayItemVoucherTemplete


class AlipayDataDataexchangeSfasdfModel(object):

    def __init__(self):
        self._adsfghjf = None
        self._easadasfd = None
        self._gdfsa = None
        self._hjgdfs = None
        self._sdfgsdfg = None
        self._wehtegf = None

    @property
    def adsfghjf(self):
        return self._adsfghjf

    @adsfghjf.setter
    def adsfghjf(self, value):
        if isinstance(value, AlipayItemVoucherTemplete):
            self._adsfghjf = value
        else:
            self._adsfghjf = AlipayItemVoucherTemplete.from_alipay_dict(value)
    @property
    def easadasfd(self):
        return self._easadasfd

    @easadasfd.setter
    def easadasfd(self, value):
        if isinstance(value, list):
            self._easadasfd = list()
            for i in value:
                self._easadasfd.append(i)
    @property
    def gdfsa(self):
        return self._gdfsa

    @gdfsa.setter
    def gdfsa(self, value):
        if isinstance(value, list):
            self._gdfsa = list()
            for i in value:
                self._gdfsa.append(i)
    @property
    def hjgdfs(self):
        return self._hjgdfs

    @hjgdfs.setter
    def hjgdfs(self, value):
        self._hjgdfs = value
    @property
    def sdfgsdfg(self):
        return self._sdfgsdfg

    @sdfgsdfg.setter
    def sdfgsdfg(self, value):
        if isinstance(value, list):
            self._sdfgsdfg = list()
            for i in value:
                self._sdfgsdfg.append(i)
    @property
    def wehtegf(self):
        return self._wehtegf

    @wehtegf.setter
    def wehtegf(self, value):
        if isinstance(value, list):
            self._wehtegf = list()
            for i in value:
                self._wehtegf.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.adsfghjf:
            if hasattr(self.adsfghjf, 'to_alipay_dict'):
                params['adsfghjf'] = self.adsfghjf.to_alipay_dict()
            else:
                params['adsfghjf'] = self.adsfghjf
        if self.easadasfd:
            if isinstance(self.easadasfd, list):
                for i in range(0, len(self.easadasfd)):
                    element = self.easadasfd[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.easadasfd[i] = element.to_alipay_dict()
            if hasattr(self.easadasfd, 'to_alipay_dict'):
                params['easadasfd'] = self.easadasfd.to_alipay_dict()
            else:
                params['easadasfd'] = self.easadasfd
        if self.gdfsa:
            if isinstance(self.gdfsa, list):
                for i in range(0, len(self.gdfsa)):
                    element = self.gdfsa[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.gdfsa[i] = element.to_alipay_dict()
            if hasattr(self.gdfsa, 'to_alipay_dict'):
                params['gdfsa'] = self.gdfsa.to_alipay_dict()
            else:
                params['gdfsa'] = self.gdfsa
        if self.hjgdfs:
            if hasattr(self.hjgdfs, 'to_alipay_dict'):
                params['hjgdfs'] = self.hjgdfs.to_alipay_dict()
            else:
                params['hjgdfs'] = self.hjgdfs
        if self.sdfgsdfg:
            if isinstance(self.sdfgsdfg, list):
                for i in range(0, len(self.sdfgsdfg)):
                    element = self.sdfgsdfg[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sdfgsdfg[i] = element.to_alipay_dict()
            if hasattr(self.sdfgsdfg, 'to_alipay_dict'):
                params['sdfgsdfg'] = self.sdfgsdfg.to_alipay_dict()
            else:
                params['sdfgsdfg'] = self.sdfgsdfg
        if self.wehtegf:
            if isinstance(self.wehtegf, list):
                for i in range(0, len(self.wehtegf)):
                    element = self.wehtegf[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.wehtegf[i] = element.to_alipay_dict()
            if hasattr(self.wehtegf, 'to_alipay_dict'):
                params['wehtegf'] = self.wehtegf.to_alipay_dict()
            else:
                params['wehtegf'] = self.wehtegf
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataexchangeSfasdfModel()
        if 'adsfghjf' in d:
            o.adsfghjf = d['adsfghjf']
        if 'easadasfd' in d:
            o.easadasfd = d['easadasfd']
        if 'gdfsa' in d:
            o.gdfsa = d['gdfsa']
        if 'hjgdfs' in d:
            o.hjgdfs = d['hjgdfs']
        if 'sdfgsdfg' in d:
            o.sdfgsdfg = d['sdfgsdfg']
        if 'wehtegf' in d:
            o.wehtegf = d['wehtegf']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayAssetPointPointprodBudgetlibCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayAssetPointPointprodBudgetlibCreateResponse, self).__init__()
        self._balance = None
        self._budget_code = None
        self._message = None

    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def budget_code(self):
        return self._budget_code

    @budget_code.setter
    def budget_code(self, value):
        self._budget_code = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value

    def parse_response_content(self, response_content):
        response = super(AlipayAssetPointPointprodBudgetlibCreateResponse, self).parse_response_content(response_content)
        if 'balance' in response:
            self.balance = response['balance']
        if 'budget_code' in response:
            self.budget_code = response['budget_code']
        if 'message' in response:
            self.message = response['message']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntfortuneContentCommunityOpenSecuaiQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneContentCommunityOpenSecuaiQueryResponse, self).__init__()
        self._secuai_open_result = None
        self._trace_id = None

    @property
    def secuai_open_result(self):
        return self._secuai_open_result

    @secuai_open_result.setter
    def secuai_open_result(self, value):
        self._secuai_open_result = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(AntfortuneContentCommunityOpenSecuaiQueryResponse, self).parse_response_content(response_content)
        if 'secuai_open_result' in response:
            self.secuai_open_result = response['secuai_open_result']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoRenthouseKaServiceCreateModel(object):

    def __init__(self):
        self._address = None
        self._ka_code = None
        self._type = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def ka_code(self):
        return self._ka_code

    @ka_code.setter
    def ka_code(self, value):
        self._ka_code = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.ka_code:
            if hasattr(self.ka_code, 'to_alipay_dict'):
                params['ka_code'] = self.ka_code.to_alipay_dict()
            else:
                params['ka_code'] = self.ka_code
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthouseKaServiceCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'ka_code' in d:
            o.ka_code = d['ka_code']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BenefitBudgetDTO import BenefitBudgetDTO
from alipay.aop.api.domain.CollectLimitRuleDTO import CollectLimitRuleDTO


class BenefitSendRuleDTO(object):

    def __init__(self):
        self._budget = None
        self._collect_limit_rules = None

    @property
    def budget(self):
        return self._budget

    @budget.setter
    def budget(self, value):
        if isinstance(value, BenefitBudgetDTO):
            self._budget = value
        else:
            self._budget = BenefitBudgetDTO.from_alipay_dict(value)
    @property
    def collect_limit_rules(self):
        return self._collect_limit_rules

    @collect_limit_rules.setter
    def collect_limit_rules(self, value):
        if isinstance(value, list):
            self._collect_limit_rules = list()
            for i in value:
                if isinstance(i, CollectLimitRuleDTO):
                    self._collect_limit_rules.append(i)
                else:
                    self._collect_limit_rules.append(CollectLimitRuleDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.budget:
            if hasattr(self.budget, 'to_alipay_dict'):
                params['budget'] = self.budget.to_alipay_dict()
            else:
                params['budget'] = self.budget
        if self.collect_limit_rules:
            if isinstance(self.collect_limit_rules, list):
                for i in range(0, len(self.collect_limit_rules)):
                    element = self.collect_limit_rules[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.collect_limit_rules[i] = element.to_alipay_dict()
            if hasattr(self.collect_limit_rules, 'to_alipay_dict'):
                params['collect_limit_rules'] = self.collect_limit_rules.to_alipay_dict()
            else:
                params['collect_limit_rules'] = self.collect_limit_rules
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BenefitSendRuleDTO()
        if 'budget' in d:
            o.budget = d['budget']
        if 'collect_limit_rules' in d:
            o.collect_limit_rules = d['collect_limit_rules']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotvspUserfordeviceCreateModel(object):

    def __init__(self):
        self._address = None
        self._area_code = None
        self._area_name = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._city_code = None
        self._city_name = None
        self._component_out_id = None
        self._ext = None
        self._isv_pid = None
        self._nation = None
        self._org_out_id = None
        self._phone = None
        self._province_code = None
        self._province_name = None
        self._unique_id = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def area_name(self):
        return self._area_name

    @area_name.setter
    def area_name(self, value):
        self._area_name = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def component_out_id(self):
        return self._component_out_id

    @component_out_id.setter
    def component_out_id(self, value):
        self._component_out_id = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def nation(self):
        return self._nation

    @nation.setter
    def nation(self, value):
        self._nation = value
    @property
    def org_out_id(self):
        return self._org_out_id

    @org_out_id.setter
    def org_out_id(self, value):
        self._org_out_id = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.area_code:
            if hasattr(self.area_code, 'to_alipay_dict'):
                params['area_code'] = self.area_code.to_alipay_dict()
            else:
                params['area_code'] = self.area_code
        if self.area_name:
            if hasattr(self.area_name, 'to_alipay_dict'):
                params['area_name'] = self.area_name.to_alipay_dict()
            else:
                params['area_name'] = self.area_name
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.component_out_id:
            if hasattr(self.component_out_id, 'to_alipay_dict'):
                params['component_out_id'] = self.component_out_id.to_alipay_dict()
            else:
                params['component_out_id'] = self.component_out_id
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.nation:
            if hasattr(self.nation, 'to_alipay_dict'):
                params['nation'] = self.nation.to_alipay_dict()
            else:
                params['nation'] = self.nation
        if self.org_out_id:
            if hasattr(self.org_out_id, 'to_alipay_dict'):
                params['org_out_id'] = self.org_out_id.to_alipay_dict()
            else:
                params['org_out_id'] = self.org_out_id
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.unique_id:
            if hasattr(self.unique_id, 'to_alipay_dict'):
                params['unique_id'] = self.unique_id.to_alipay_dict()
            else:
                params['unique_id'] = self.unique_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotvspUserfordeviceCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'area_code' in d:
            o.area_code = d['area_code']
        if 'area_name' in d:
            o.area_name = d['area_name']
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'component_out_id' in d:
            o.component_out_id = d['component_out_id']
        if 'ext' in d:
            o.ext = d['ext']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'nation' in d:
            o.nation = d['nation']
        if 'org_out_id' in d:
            o.org_out_id = d['org_out_id']
        if 'phone' in d:
            o.phone = d['phone']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'unique_id' in d:
            o.unique_id = d['unique_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenOrderDetail import OpenOrderDetail


class AlipayDataDataserviceAdOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceAdOrderQueryResponse, self).__init__()
        self._order_detail = None

    @property
    def order_detail(self):
        return self._order_detail

    @order_detail.setter
    def order_detail(self, value):
        if isinstance(value, OpenOrderDetail):
            self._order_detail = value
        else:
            self._order_detail = OpenOrderDetail.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceAdOrderQueryResponse, self).parse_response_content(response_content)
        if 'order_detail' in response:
            self.order_detail = response['order_detail']
